setwd('C:/Users/x1/Dropbox/')

library(ggplot2)
library(sf)
#install.packages('rnaturalearth')
library(rnaturalearth)

# Read data
df <- readxl::read_xlsx('NMNZ, NIWA and AWMM holdings of Epigonichthys hectori (Benham, 1901) - with additional records_suppl table S1.xlsx')
df$`Depth From` <- as.numeric(as.character(df$`Depth From`))
df$`Depth To` <- as.numeric(as.character(df$`Depth To`))
df$Depth_m <- rowMeans(df[, c("Depth From","Depth To")]) # Get 'mean of depth range'
df$Year <- as.numeric(substr(df$`Date Visited From`, nchar(df$`Date Visited From`) - 3, nchar(df$`Date Visited From`)))
df$`No. of specimens` <- as.numeric(df$`No. of specimens`)

# Download country polygons data
world <- ne_countries(scale = "medium", returnclass = "sf") # 'small', 'medium', 'large'

# Filter data for New Zealand
nz <- world[world$name == "New Zealand", ]

# Plot distribution
ggplot() +
  geom_sf(data = nz, fill = "ivory", color = "black") +
  geom_point(data = df, aes(x = `Long. Centroid Decimal`, y = `Lat. Centroid Decimal`), fill = 'red', color = 'darkred', size = 2.1, shape = 21, alpha = .4)+
  geom_segment(aes(xend = 174.63, yend = -35.8, x = 176, y = -35),
               arrow = arrow(length = unit(0.35, "cm"))) +
  geom_text(aes(x = 176.6, y = -34.9, label = 'New')) +
  coord_sf(xlim = c(170.5, 179.5), ylim = c(-42.5,-34)) +  
  ggtitle('Records')+xlab('Longitude')+ylab('Latitude')+
  theme_classic()+
  theme(panel.background = element_rect(fill = "lightblue"))

ggsave('NZ_records.png', plot = last_plot(), width = 6.3, height = 5, unit = 'in')

require(dplyr)
p.depth <- ggplot() +
  geom_sf(data = nz, fill = "ivory", color = "black") +
  geom_point(data = subset(df, is.na(df$Depth_m) & (df$`Type Status` != 'Holotype' | is.na(df$`Type Status`))), 
             aes(x = `Long. Centroid Decimal`, y = `Lat. Centroid Decimal`, fill = as.numeric(Depth_m)), size = 1.1, shape = 21)+
  geom_point(data = subset(df, !is.na(df$Depth_m) & (df$`Type Status` != 'Holotype' | is.na(df$`Type Status`))), 
             aes(x = `Long. Centroid Decimal`, y = `Lat. Centroid Decimal`, fill = as.numeric(Depth_m)), size = 1.1, shape = 21)+
  geom_point(data = subset(df, df$`Type Status` == 'Holotype'), aes(x = `Long. Centroid Decimal`, y = `Lat. Centroid Decimal`, shape = `Type Status`), size = 1.6)+
  geom_segment(aes(xend = 174.67, yend = -35.76, x = 176, y = -35),
               arrow = arrow(length = unit(0.35, "cm"))) +
  geom_text(aes(x = 176.8, y = -35.15, label = 'Intertidal\n(2023)'), size = 3) +
  geom_segment(aes(xend = 174.96, yend = -41.25, x = 177, y = -41),
               arrow = arrow(length = unit(0.35, "cm"))) +
  geom_text(aes(x = 177.8, y = -41.17, label = 'Intertidal\n(2022)'), size = 3) +
  coord_sf(xlim = c(170.5, 179.5), ylim = c(-41.5,-34.5)) +
  #scale_fill_gradient(name = 'Depth (m)', low = "white", high = "green")+
  scale_fill_gradientn(name = 'Depth (m)', colours = rainbow(4))+
  scale_shape_manual(name = 'Type', values = c(13), labels = c("Holotype" = "Type locality"))+
  guides(fill = guide_colorbar(reverse = T)) +
  ggtitle('Geographic and depth distribution of recorded specimens')+xlab('Longitude')+ylab('Latitude')+
  theme_classic()+
  theme(panel.background = element_rect(fill = "lightblue"))+guides(shape = guide_legend(title = NULL))
p.depth
ggsave('NZ_records_depth.png', plot = p.depth, width = 6.3, height = 5, unit = 'in')


p.inds <- ggplot() +
  geom_sf(data = nz, fill = "ivory", color = "black") +
  geom_point(data = df, aes(x = `Long. Centroid Decimal`, y = `Lat. Centroid Decimal`, size = `No. of specimens`), shape = 21)+
  geom_segment(aes(xend = 174.63, yend = -35.8, x = 176, y = -35),
               arrow = arrow(length = unit(0.35, "cm"))) +
  geom_text(aes(x = 176.6, y = -34.9, label = 'New')) +
  scale_size(name = 'Individuals') +
  coord_sf(xlim = c(170.5, 179.5), ylim = c(-42.5,-34)) +
  ggtitle('Individuals')+xlab('Longitude')+ylab('Latitude')+
  theme_classic()+
  theme(panel.background = element_rect(fill = "lightblue"))
p.inds

p.year <- ggplot() +
  geom_sf(data = nz, fill = "ivory", color = "black") +
  geom_point(data = df, aes(x = `Long. Centroid Decimal`, y = `Lat. Centroid Decimal`, fill = as.numeric(Year)), size = 2.5, shape = 21)+
  geom_segment(aes(xend = 174.63, yend = -35.8, x = 176, y = -35),
               arrow = arrow(length = unit(0.35, "cm"))) +
  geom_text(aes(x = 176.6, y = -34.9, label = 'New')) +
  coord_sf(xlim = c(170.5, 179.5), ylim = c(-42.5,-34)) + 
  scale_fill_gradient(name = 'Year', low = "white", high = "red")+
  guides(fill = guide_colorbar(reverse = T)) +
  ggtitle('Year')+xlab('Longitude')+ylab('Latitude')+
  theme_classic()+
  theme(panel.background = element_rect(fill = "lightblue"))
p.year

